######################################################
##                                                  ##
##                 prevR 1.0                        ##
##            by Joseph LARMARANGE                  ##
##                                                  ##
##          Fichier de dmonstration                ##
##                                                  ##
######################################################

data(alicante)
require(gstat)

par(ask = TRUE)

message("Data can be imported with make.ind.spps, make.clust.dbf, lake.cities.csv and make.boundary.dcw. See help files.")

# Visualisation des clusters et du nombre de personnes enqutes

map.clust(alicante.clust, alicante.bounds, type='count', new.window=FALSE, main='Number of tested persons by cluster', factor.size=0.15)
map.clust(alicante.clust, alicante.bounds, type='flower', new.window=FALSE, main='Number of HIV positive persons by cluster')
map.clust(alicante.clust, alicante.bounds, type='urb', new.window=FALSE, main='Clusters by type of residence')

# Choix des villes

map.cities(alicante.cities, alicante.bounds, min.population=100000, new.window=FALSE, main='Main cities of Alicante')
main.cities <- alicante.cities[alicante.cities$population > 100000, ]
alicante.clust <- calcul.dist.cities(alicante.clust, main.cities, type='all', dist=25)
verif.urb(alicante.clust)
main.cities <- alicante.cities[alicante.cities$population > 250000, ]
alicante.clust <- calcul.dist.cities(alicante.clust, main.cities, type='all', dist=25)
verif.urb(alicante.clust)
infos.prev(alicante.clust)
map.clust(alicante.clust, alicante.bounds, type='urb', new.window=FALSE, var.urb='urban.area', inverse=TRUE,
	main='Clusters in urban agglomeration')

# Premier lissage - juste selon N

alicante.prev <- estimate.prev(alicante.clust, N=seq(100, 400, 50), R=Inf, U=FALSE)
str(alicante.prev)
alicante.prev.n250 <- extract.data(alicante.prev, value=c(250, Inf, 0))
str(alicante.prev.n250)
infos.prev(alicante.prev.n250)


# Second lissage - complet

alicante.prev <- estimate.prev(alicante.clust, N=c(100,250), R=c(128,Inf), U=2, merge.result=TRUE)
str(alicante.prev)


# Krigeage

show.vgms()
alicante.krige <- krige.prev(alicante.prev, boundary=alicante.bounds, 
	formula=c(est.prevalence.N100.RInf.U0~1,est.prevalence.N250.RInf.U0~1,est.prevalence.N250.R128.U0~1,
		est.prevalence.N250.R128.U6~1,circle.radius.N250.R128.U6~1,quality.indicator.N250.R128.U6~1),
	model=list(vgm(53.58,'Exp',0.56),vgm(48.97,'Exp',1.06),vgm(49.19,'Exp',1.07),vgm(42.47,'Exp',0.58),
		vgm(1056,'Exp',0.89),vgm(150000,'Exp',2.1)),
	type='model', ask.cell.size=FALSE, cell.size=0.075, show.variogram=FALSE)

# Reprsentation graphique

spplot(alicante.krige, c('est.prevalence.N100.RInf.U0.pred','est.prevalence.N250.RInf.U0.pred',
	'est.prevalence.N250.R128.U0.pred','est.prevalence.N250.R128.U6.pred'),
	col.regions=prevR.colors.red(21), cuts=20,main='Estimated prevalence with several parameters')
x11()
spplot(alicante.krige, 'circle.radius.N250.R128.U6.pred', col.regions=prevR.colors.blue(21), cuts=20,
	main='Radius of circles - N=250 R=128 U=6')
x11()
spplot(alicante.krige, 'quality.indicator.N250.R128.U6.pred', col.regions=prevR.colors.green.inverse(21), cuts=20,
	main='Quality indicator - N=250 R=128 U=6')
x11()
prevR.demo.pal(25)

message("Data and results can be exported with write.asciigrid, write.prev.shp, write.boundary.shp, write.dbf and write.txt. See help files.")

par (ask = FALSE)
